@@ -2,7 +2,6 @@
 import io
 import json
 import os
-from typing import List
 from typing import Any, Dict, List
 import uuid
 
@@ -187,7 +186,7 @@ def run(ctx: click.Context, source: str, journal_path: str = "./journal.json",
 
     journal = run_experiment(
         experiment, settings=settings, strategy=hypothesis_strategy,
-        schedule=schedule)
+        schedule=schedule, experiment_vars=experiment_vars)
     has_deviated = journal.get("deviated", False)
     has_failed = journal["status"] != "completed"
 
@@ -454,7 +453,7 @@ def discover(ctx: click.Context, package: str,
     return discovery
 
 
-@cli.command()
+@cli.command() #noqa: C901
 @click.option('--discovery-path', default="./discovery.json",
               help='Path to the discovery outcome.',
               show_default=True, type=click.Path(exists=False))
@@ -463,7 +462,7 @@ def discover(ctx: click.Context, package: str,
               help='Path where to save the experiment (.yaml or .json)',
               show_default=True)
 @click.pass_context
-def init(ctx: click.Context, discovery_path: str = "./discovery.json",
+def init(ctx: click.Context, discovery_path: str = "./discovery.json", #noqa: C901
          experiment_path: str = "./experiment.json") -> Experiment:
     """Initialize a new experiment from discovered capabilities."""
     settings = load_settings(ctx.obj["settings_path"])
@@ -604,7 +603,7 @@ def is_yaml(experiment_path: str) -> bool:
     return ext.lower() in (".yaml", ".yml")
 
 
-def add_activities(activities: List[Activity], pool: List[Activity],
+def add_activities(activities: List[Activity], pool: List[Activity],  #noqa: C901
                    with_tolerance: bool = False):
     """
     Add activities to the given pool.
